@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.44';
+$Geo::Address::Formatter::VERSION = '1.45';
 use strict;
 use warnings;
 
@@ -215,6 +215,13 @@ sub _sanity_cleaning {
     ){
         delete $rh_components->{'postcode'};
     }
+
+    # catch values containing URLs
+    foreach my $c (keys %$rh_components){
+        if ($rh_components->{$c} =~ m|https?://|){
+            delete $rh_components->{$c};
+        }
+    }
     return;
 }
 
@@ -398,7 +405,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.44
+version 1.45
 
 =head1 SYNOPSIS
 
